-----------------------------------------------------------------------------------------------
-- Client Lua Script for AutoFocus
-- Copyright (c) NCsoft. All rights reserved
-----------------------------------------------------------------------------------------------
 
require "Window"
 
-----------------------------------------------------------------------------------------------
-- AutoFocus Module Definition
-----------------------------------------------------------------------------------------------
local AutoFocus = {} 
 
-----------------------------------------------------------------------------------------------
-- Constants
-----------------------------------------------------------------------------------------------
-- e.g. local kiExampleVariableMax = 999
 
-----------------------------------------------------------------------------------------------
-- Initialization
-----------------------------------------------------------------------------------------------
function AutoFocus:new(o)
    o = o or {}
    setmetatable(o, self)
    self.__index = self 

    -- initialize variables here

    return o
end

function AutoFocus:Init()
	local bHasConfigureFunction = false
	local strConfigureButtonText = ""
	local tDependencies = {
		-- "UnitOrPackageName",
	}
    Apollo.RegisterAddon(self, bHasConfigureFunction, strConfigureButtonText, tDependencies)
end
 

-----------------------------------------------------------------------------------------------
-- AutoFocus OnLoad
-----------------------------------------------------------------------------------------------
function AutoFocus:OnLoad()
    -- load our form file
	self.xmlDoc = XmlDoc.CreateFromFile("AutoFocus.xml")
	self.xmlDoc:RegisterCallback("OnDocLoaded", self)
end

-----------------------------------------------------------------------------------------------
-- AutoFocus OnDocLoaded
-----------------------------------------------------------------------------------------------
function AutoFocus:OnDocLoaded()

	if self.xmlDoc ~= nil and self.xmlDoc:IsLoaded() then
	    self.wndMain = Apollo.LoadForm(self.xmlDoc, "AutoFocusForm", nil, self)
		if self.wndMain == nil then
			Apollo.AddAddonErrorText(self, "Could not load the main window for some reason.")
			return
		end
		
	    self.wndMain:Show(false, true)

		-- if the xmlDoc is no longer needed, you should set it to nil
		-- self.xmlDoc = nil
		
		-- Register handlers for events, slash commands and timer, etc.
		-- e.g. Apollo.RegisterEventHandler("KeyDown", "OnKeyDown", self)
		Apollo.RegisterSlashCommand("autofocus", "OnAutoFocusOn", self)
		
		-- Group Events.
		Apollo.RegisterEventHandler("Group_Join",						"onAutoFocusGroupJoined", self)
		Apollo.RegisterEventHandler("Group_Left", 						"onAutoFocusGroupLeft", self)

		self.timer = ApolloTimer.Create(1.0, true, "OnTimer", self)

		-- Do additional Addon initialization here
	end
end

-----------------------------------------------------------------------------------------------
-- AutoFocus Functions
-----------------------------------------------------------------------------------------------
-- Define general functions here

function AutoFocus:OnAutoFocusOn() -- on SlashCommand "/autofocus"
	self.wndMain:Invoke() -- show the window
end

function AutoFocus:OnTimer() --primary loop for addon
	local uMyTank = AutoFocus:getTank()
	local player = GameLib.GetPlayerUnit()
	if uMyTank then
			self.wndMain:FindChild("strTankName"):SetText(uMyTank:GetName())
	end
	if uMyTank ~= nil and uMyTank:GetTarget() ~= nil then
		self.wndMain:FindChild("strFocusName"):SetText(uMyTank:GetTarget():GetName())
		player:SetAlternateTarget(uMyTank:GetTarget())
	end
end

function AutoFocus:getTank() -- returns tank group unit
		for i=1, GroupLib.GetMemberCount() do
			local tGroupMember = GroupLib.GetGroupMember(i)
			local tGroupMemberUnit = GroupLib.GetUnitForGroupMember(i)
			local GroupMemberRole = ""
			if tGroupMember.bHealer then
				GroupMemberRole = "Healer"
			elseif tGroupMember.bTank then
				GroupMemberRole = "Tank"
			else
				GroupMemberRole = "DPS"
			end
		
			if GroupMemberRole == "Tank" then
				-- here is where you would add this person to the *list* of healers	
				return tGroupMemberUnit
			end
		end
end

function AutoFocus:onAutoFocusGroupJoined()
	self.wndMain:Invoke()
end

function AutoFocus:onAutoFocusGroupLeft()

end

-----------------------------------------------------------------------------------------------
-- AutoFocusForm Functions
-----------------------------------------------------------------------------------------------
function AutoFocus:OnOK() -- when the OK button is clicked
	self.wndMain:Close() -- hide the window
end

function AutoFocus:OnCancel() -- when the Cancel button is clicked
	self.wndMain:Close()
end

function AutoFocus:onAutoFocusReset( wndHandler, wndControl, eMouseButton ) --  manual reset for values
	local uMyTank = AutoFocus:getTank()
	local player = GameLib.GetPlayerUnit()
	if uMyTank then
		self.wndMain:FindChild("strTankName"):SetText(uMyTank:GetName())
		if uMyTank:GetTarget() then
			self.wndMain:FindChild("strFocusName"):SetText(uMyTank:GetTarget():GetName())
			player:SetAlternateTarget(uMyTank:GetTarget())
		end
	end
end

-----------------------------------------------------------------------------------------------
-- AutoFocus Instance
-----------------------------------------------------------------------------------------------
local AutoFocusInst = AutoFocus:new()
AutoFocusInst:Init()
